/****************************************************************************
** Meta object code from reading C++ file 'resultwatcher.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-activities-stats-6.6.5/src/resultwatcher.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resultwatcher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KActivities5Stats13ResultWatcherE_t {};
} // unnamed namespace

template <> constexpr inline auto KActivities::Stats::ResultWatcher::qt_create_metaobjectdata<qt_meta_tag_ZN11KActivities5Stats13ResultWatcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KActivities::Stats::ResultWatcher",
        "resultScoreUpdated",
        "",
        "resource",
        "score",
        "lastUpdate",
        "firstUpdate",
        "resultRemoved",
        "resultLinked",
        "resultUnlinked",
        "resourceTitleChanged",
        "title",
        "resourceMimetypeChanged",
        "mimetype",
        "resultsInvalidated"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'resultScoreUpdated'
        QtMocHelpers::SignalData<void(const QString &, double, uint, uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Double, 4 }, { QMetaType::UInt, 5 }, { QMetaType::UInt, 6 },
        }}),
        // Signal 'resultRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'resultLinked'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'resultUnlinked'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'resourceTitleChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'resourceMimetypeChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'resultsInvalidated'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ResultWatcher, qt_meta_tag_ZN11KActivities5Stats13ResultWatcherE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KActivities::Stats::ResultWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KActivities5Stats13ResultWatcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KActivities5Stats13ResultWatcherE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KActivities5Stats13ResultWatcherE_t>.metaTypes,
    nullptr
} };

void KActivities::Stats::ResultWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResultWatcher *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resultScoreUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4]))); break;
        case 1: _t->resultRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->resultLinked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->resultUnlinked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->resourceTitleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->resourceMimetypeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->resultsInvalidated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResultWatcher::*)(const QString & , double , uint , uint )>(_a, &ResultWatcher::resultScoreUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultWatcher::*)(const QString & )>(_a, &ResultWatcher::resultRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultWatcher::*)(const QString & )>(_a, &ResultWatcher::resultLinked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultWatcher::*)(const QString & )>(_a, &ResultWatcher::resultUnlinked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultWatcher::*)(const QString & , const QString & )>(_a, &ResultWatcher::resourceTitleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultWatcher::*)(const QString & , const QString & )>(_a, &ResultWatcher::resourceMimetypeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResultWatcher::*)()>(_a, &ResultWatcher::resultsInvalidated, 6))
            return;
    }
}

const QMetaObject *KActivities::Stats::ResultWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KActivities::Stats::ResultWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KActivities5Stats13ResultWatcherE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KActivities::Stats::ResultWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KActivities::Stats::ResultWatcher::resultScoreUpdated(const QString & _t1, double _t2, uint _t3, uint _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void KActivities::Stats::ResultWatcher::resultRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KActivities::Stats::ResultWatcher::resultLinked(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KActivities::Stats::ResultWatcher::resultUnlinked(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KActivities::Stats::ResultWatcher::resourceTitleChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KActivities::Stats::ResultWatcher::resourceMimetypeChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KActivities::Stats::ResultWatcher::resultsInvalidated()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
