// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "plasma-activities-stats-logsettings.h"


Q_LOGGING_CATEGORY(PLASMA_ACTIVITIES_STATS_LOG, "kde.plasma.activitiesstats", QtInfoMsg)

